import { CommonModule } from '@angular/common';
import { EventEmitter, Component, Input, Output, Directive, TemplateRef, ViewContainerRef, ChangeDetectionStrategy, ViewEncapsulation, ChangeDetectorRef, ViewChild, ContentChildren, NgModule } from '@angular/core';
import { ActivatedRoute, Router, RouterModule } from '@angular/router';
import { NtLabelModule } from '@ng-tangram/components/label';
import { Subject } from 'rxjs';
import { delay, takeUntil } from 'rxjs/operators';

class NtQueryParamComponent {
    constructor() {
        this.remove = new EventEmitter();
    }
    emitRemoveEvent() {
        this.remove.emit(this);
    }
}
NtQueryParamComponent.decorators = [
    { type: Component, args: [{
                selector: 'nt-query-param',
                template: `
    <nt-label class="primary">
      {{label}}：
      <ng-content></ng-content>
      <span (click)="emitRemoveEvent()" class="fas fa-times" class="clear-icon"></span>
    </nt-label>
  `,
                host: {
                    'class': 'nt-query-param'
                }
            },] }
];
NtQueryParamComponent.ctorParameters = () => [];
NtQueryParamComponent.propDecorators = {
    label: [{ type: Input }],
    remove: [{ type: Output }]
};

class NtQueryParamDefDirective {
    constructor(template) {
        this.template = template;
    }
}
NtQueryParamDefDirective.decorators = [
    { type: Directive, args: [{
                selector: '[ntQueryParamDef]',
            },] }
];
NtQueryParamDefDirective.ctorParameters = () => [
    { type: TemplateRef }
];
NtQueryParamDefDirective.propDecorators = {
    key: [{ type: Input, args: ['ntQueryParamDefKey',] }]
};

class NtQueryParamsOutletDirective {
    constructor(viewContainerRef) {
        this.viewContainerRef = viewContainerRef;
    }
}
NtQueryParamsOutletDirective.decorators = [
    { type: Directive, args: [{
                selector: '[ntQueryParamsOutlet]'
            },] }
];
NtQueryParamsOutletDirective.ctorParameters = () => [
    { type: ViewContainerRef }
];

class NtQueryParamsComponent {
    constructor(viewContainerRef, route, router, _changeDetectorRef) {
        this.viewContainerRef = viewContainerRef;
        this.route = route;
        this.router = router;
        this._changeDetectorRef = _changeDetectorRef;
        this._destroy = new Subject();
    }
    ngAfterViewInit() {
        this.route.queryParams
            .pipe(delay(0), takeUntil(this._destroy))
            .subscribe(query => {
            this._clearViewContainer();
            this._attachmentQueryParamItems(query);
        });
        this.queryParamDefs.changes.subscribe(items => {
            this._clearViewContainer();
        });
    }
    ngOnDestroy() {
        this._destroy.next();
        this._destroy.complete();
    }
    clearAll() {
        this.router.navigate(['./'], { relativeTo: this.route });
    }
    _clearViewContainer() {
        this._outlet.viewContainerRef.clear();
    }
    _attachmentQueryParamItems(query) {
        const defs = this.queryParamDefs.toArray();
        const queryParamKeys = Object.keys(query);
        defs.forEach((def) => {
            if (queryParamKeys.includes(def.key)) {
                const context = { $implicit: query[def.key] };
                this._outlet.viewContainerRef.createEmbeddedView(def.template, context);
            }
        });
        this._changeDetectorRef.markForCheck();
    }
}
NtQueryParamsComponent.decorators = [
    { type: Component, args: [{
                selector: 'nt-query-params',
                template: "<ng-container *ntQueryParamsOutlet></ng-container>\n<div class=\"clear-all-icon\" (click)=\"clearAll()\">\u6E05\u9664</div>\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None,
                host: {
                    'class': 'nt-query-params'
                }
            },] }
];
NtQueryParamsComponent.ctorParameters = () => [
    { type: ViewContainerRef },
    { type: ActivatedRoute },
    { type: Router },
    { type: ChangeDetectorRef }
];
NtQueryParamsComponent.propDecorators = {
    _outlet: [{ type: ViewChild, args: [NtQueryParamsOutletDirective, { static: true },] }],
    queryParamDefs: [{ type: ContentChildren, args: [NtQueryParamDefDirective, { descendants: true },] }]
};

class NtQueryParamsModule {
}
NtQueryParamsModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    RouterModule,
                    NtLabelModule,
                ],
                declarations: [
                    NtQueryParamsComponent,
                    NtQueryParamDefDirective,
                    NtQueryParamsOutletDirective,
                    NtQueryParamComponent
                ],
                exports: [
                    NtQueryParamDefDirective,
                    NtQueryParamsOutletDirective,
                    NtQueryParamsComponent,
                    NtQueryParamComponent
                ]
            },] }
];

export { NtQueryParamComponent, NtQueryParamDefDirective, NtQueryParamsComponent, NtQueryParamsModule, NtQueryParamsOutletDirective as ɵa };
//# sourceMappingURL=query-params.js.map
