import { coerceNumberProperty } from '@angular/cdk/coercion';
import { TemplatePortal, PortalModule } from '@angular/cdk/portal';
import { Directive, TemplateRef, Component, ChangeDetectionStrategy, ViewEncapsulation, IterableDiffers, ChangeDetectorRef, ViewContainerRef, Input, ViewChild, ContentChildren, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { NtDropdownModule } from '@ng-tangram/components/dropdown';

class NtActionDefDirective {
    constructor(template) {
        this.template = template;
    }
}
NtActionDefDirective.decorators = [
    { type: Directive, args: [{ selector: '[ntReactiveActionDef]' },] }
];
NtActionDefDirective.ctorParameters = () => [
    { type: TemplateRef }
];
class NtActionDirective {
}
NtActionDirective.decorators = [
    { type: Directive, args: [{
                selector: 'nt-reactive-action, [nt-reactive-action]',
                host: {
                    'class': 'nt-reactive-action'
                }
            },] }
];

class NtReactiveActionBarComponent {
    constructor(_differs, _changeDetectorRef, _viewContainerRef) {
        this._differs = _differs;
        this._changeDetectorRef = _changeDetectorRef;
        this._viewContainerRef = _viewContainerRef;
        this._columns = 3;
        this._rows = 1;
        this.rowOverflow = false;
        this._dropdownActionItems = [];
        this._normalItems = [];
    }
    get columns() { return this._columns; }
    set columns(value) {
        this._columns = coerceNumberProperty(value, 1);
    }
    get rows() { return this._rows; }
    set rows(value) {
        this._rows = coerceNumberProperty(value, 1);
    }
    ngOnInit() { }
    ngOnChanges(changes) {
        const change = changes.columns || changes.rows;
        if (change && !change.firstChange) {
            this.calculateRenderItemRows();
        }
    }
    ngAfterViewInit() {
        this._dropdownPortal = new TemplatePortal(this._dropdownContent, this._viewContainerRef);
    }
    ngAfterContentInit() {
        this.calculateRenderItemRows();
        this._itemDefs.changes.subscribe(() => {
            this.calculateRenderItemRows();
        });
    }
    ngAfterContentChecked() {
    }
    renderItems() { }
    calculateRenderItemRows() {
        const length = this._itemDefs.length;
        const rows = Math.ceil(length / this.columns);
        this.rowOverflow = rows > this.rows;
        const itemsArray = this._itemDefs.toArray();
        ;
        if (this.rowOverflow) {
            this._normalItems = itemsArray.splice(0, this.columns * this.rows - 1);
            this._dropdownActionItems = itemsArray;
        }
        else {
            this._normalItems = itemsArray;
        }
    }
}
NtReactiveActionBarComponent.decorators = [
    { type: Component, args: [{
                selector: 'nt-reactive-action-bar, [nt-reactive-action-bar]',
                template: "<ng-container *ngFor=\"let def of _normalItems; let $index = index\">\n  <ng-container *ngTemplateOutlet=\"def?.template;\"></ng-container><br *ngIf=\"($index + 1) % columns === 0\">\n</ng-container>\n<nt-reactive-action nt-dropdown position=\"bottomRight\" trigger=\"click\" *ngIf=\"rowOverflow\">\n  <span class=\"fas fa-ellipsis-h\"></span>\n  <nt-dropdown-pane class=\"action-dropdown-pane\" arrow autosize size=\"tiny\">\n    <ng-template [cdkPortalOutlet]=\"_dropdownPortal\"></ng-template>\n  </nt-dropdown-pane>\n</nt-reactive-action>\n<ng-template #dropdownContent>\n  <ul class=\"menu vertical action-dropdown-menu\">\n    <li *ngFor=\"let def of _dropdownActionItems\">\n      <a>\n        <ng-container *ngTemplateOutlet=\"def?.template\"></ng-container>\n      </a>\n    </li>\n  </ul>\n</ng-template>\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None,
                host: {
                    class: 'nt-reactive-action-bar'
                },
                styles: [""]
            },] }
];
NtReactiveActionBarComponent.ctorParameters = () => [
    { type: IterableDiffers },
    { type: ChangeDetectorRef },
    { type: ViewContainerRef }
];
NtReactiveActionBarComponent.propDecorators = {
    columns: [{ type: Input }],
    rows: [{ type: Input }],
    _dropdownContent: [{ type: ViewChild, args: ['dropdownContent', { static: false },] }],
    _itemDefs: [{ type: ContentChildren, args: [NtActionDefDirective,] }]
};

class NtReactiveActionModule {
}
NtReactiveActionModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    PortalModule,
                    NtDropdownModule,
                ],
                exports: [
                    NtReactiveActionBarComponent,
                    NtActionDefDirective,
                    NtActionDirective
                ],
                declarations: [
                    NtReactiveActionBarComponent,
                    NtActionDefDirective,
                    NtActionDirective
                ],
            },] }
];

export { NtActionDefDirective, NtActionDirective, NtReactiveActionBarComponent, NtReactiveActionModule };
//# sourceMappingURL=reactive-action.js.map
