import { Action, Selector, State, StateContext } from '@ngxs/store';

import { UIActions, UIFontSize, UISidebarMode } from './user-interface.actions';

export interface UIStateModel {
  theme: string;
  sidebarMode: UISidebarMode;
  fontSize: UIFontSize;
  skin?: string;
  reactiveMode: boolean;
  reactiveSidebarMode: UISidebarMode;
}

const initialState = (): UIStateModel => ({
  theme: 'dark',
  reactiveMode: false,
  reactiveSidebarMode: UISidebarMode.Default,
  fontSize: UIFontSize.大,
  sidebarMode: UISidebarMode.Default,
});

@State<UIStateModel>({
  name: 'ui',
  defaults: initialState()
})
export class UIState {

  @Selector()
  static isDropdownMode(state: UIStateModel) {
    if (state.reactiveMode) {
      return state.reactiveSidebarMode === UISidebarMode.Dropdown;
    } else {
      return state.sidebarMode === UISidebarMode.Dropdown;
    }
  }

  @Selector()
  static isDropdownSidebar(state: UIStateModel) {
    return state.sidebarMode === UISidebarMode.Dropdown;
  }


  @Selector()
  static currentTheme(state: UIStateModel) {
    return state.theme;
  }

  @Action(UIActions.ChangeSidebarMode)
  changeSidebarMode(context: StateContext<UIStateModel>, { sidebarMode }: UIActions.ChangeSidebarMode) {
    return context.patchState({ sidebarMode });
  }

  @Action(UIActions.ChangeTheme)
  changeTheme(context: StateContext<UIStateModel>, { theme }: UIActions.ChangeTheme) {
    return context.patchState({ theme });
  }

  @Action(UIActions.ChangeFontSize)
  changeFontSize(context: StateContext<UIStateModel>, { fontSize }: UIActions.ChangeFontSize) {
    return context.patchState({ fontSize });
  }

  @Action(UIActions.ToggleReactiveMode)
  toggleReactiveMode(context: StateContext<UIStateModel>, { open }: UIActions.ToggleReactiveMode) {
    return context.patchState({ reactiveMode: open });
  }

  @Action(UIActions.ChangeReactiveSidebarMode)
  changeReactiveSidebarMode(context: StateContext<UIStateModel>, { sidebarMode }: UIActions.ChangeReactiveSidebarMode) {
    return context.patchState({ reactiveSidebarMode: sidebarMode });
  }
}
